@@ -65,7 +65,7 @@ numpy_numbers = (
     np_int8, np_int16, np_int32, np_int64, np_uint8,
     np_uint16, np_uint32, np_uint64, np_intp, np_uintp,
     np_float32, np_float64, np_float_, np_complex64,
-    np_complex128, np_complex_, )
+    np_complex128, np_complex_,)
 
 numpy_dtypes = set(numpy_numbers)
 numpy_dtypes.add(np_bool_)
@@ -112,7 +112,6 @@ if DICT_IS_SORTED:
 else:
     dict_ = OrderedDictPlus  # pragma: no cover. Only used in pypy3 and py3.5
 
-
 if py4:
     logger.warning('Python 4 is not supported yet. Switching logic to Python 3.')  # pragma: no cover
     py3 = True  # pragma: no cover
@@ -121,7 +120,6 @@ if py2:  # pragma: no cover
     sys.exit('Python 2 is not supported anymore. The last version of DeepDiff that supported Py2 was 3.3.0')
 
 pypy3 = py3 and hasattr(sys, "pypy_translation_info")
-py3_5 = py_current_version == Decimal('3.5')
 
 strings = (str, bytes)  # which are both basestring
 unicode_type = str
@@ -185,18 +183,25 @@ class NotPresent:  # pragma: no cover
     in the future.
     We previously used None for this but this caused problem when users actually added and removed None. Srsly guys? :D
     """
+
     def __repr__(self):
         return 'not present'  # pragma: no cover
 
     __str__ = __repr__
 
 
+class CannotCompare(Exception):
+    """
+    Exception when two items cannot be compared in the compare function.
+    """
+    pass
+
+
 unprocessed = Unprocessed()
 skipped = Skipped()
 not_hashed = NotHashed()
 notpresent = NotPresent()
 
-
 # Disabling remapping from old to new keys since the mapping is deprecated.
 RemapDict = dict_
 
@@ -309,7 +314,9 @@ def type_in_type_group(item, type_group):
 
 
 def type_is_subclass_of_type_group(item, type_group):
-    return isinstance(item, type_group) or issubclass(item, type_group) or type_in_type_group(item, type_group)
+    return isinstance(item, type_group) \
+           or (isinstance(item, type) and issubclass(item, type_group)) \
+           or type_in_type_group(item, type_group)
 
 
 def get_doc(doc_filename):
@@ -418,7 +425,6 @@ class _NotFound:
 
 not_found = _NotFound()
 
-
 warnings.simplefilter('once', DeepDiffDeprecationWarning)
 
 
@@ -441,6 +447,11 @@ class OrderedSetPlus(OrderedSet):
         del self.map[elem]
         return elem
 
+    def __repr__(self):
+        return str(list(self))
+
+    __str__ = __repr__
+
 
 class RepeatedTimer:
     """
@@ -480,8 +491,26 @@ class RepeatedTimer:
         return duration
 
 
+def _eval_decimal(params):
+    return Decimal(params)
+
+
+def _eval_datetime(params):
+    params = f'({params})'
+    params = literal_eval(params)
+    return datetime.datetime(*params)
+
+
+def _eval_date(params):
+    params = f'({params})'
+    params = literal_eval(params)
+    return datetime.date(*params)
+
+
 LITERAL_EVAL_PRE_PROCESS = [
-    ('Decimal(', ')', Decimal),
+    ('Decimal(', ')', _eval_decimal),
+    ('datetime.datetime(', ')', _eval_datetime),
+    ('datetime.date(', ')', _eval_date),
 ]
 
 
@@ -495,8 +524,8 @@ def literal_eval_extended(item):
         for begin, end, func in LITERAL_EVAL_PRE_PROCESS:
             if item.startswith(begin) and item.endswith(end):
                 # Extracting and removing extra quotes so for example "Decimal('10.1')" becomes "'10.1'" and then '10.1'
-                item2 = item[len(begin): -len(end)].strip('\'\"')
-                return func(item2)
+                params = item[len(begin): -len(end)].strip('\'\"')
+                return func(params)
         raise
 
 
@@ -570,7 +599,7 @@ def get_homogeneous_numpy_compatible_type_of_seq(seq):
     iseq = iter(seq)
     first_type = type(next(iseq))
     if first_type in {int, float, Decimal}:
-        type_ = first_type if all((type(x) is first_type) for x in iseq ) else False
+        type_ = first_type if all((type(x) is first_type) for x in iseq) else False
         return PYTHON_TYPE_TO_NUMPY_TYPE.get(type_, False)
     else:
         return False
