@@ -116,7 +116,7 @@ class SerializationMixin:
         else:
             logger.error('jsonpickle library needs to be installed in order to run from_json_pickle')  # pragma: no cover. Json pickle is getting deprecated.
 
-    def to_json(self, default_mapping=None):
+    def to_json(self, default_mapping=None, **kwargs):
         """
         Dump json of the text view.
         **Parameters**
@@ -127,6 +127,8 @@ class SerializationMixin:
         If you have a certain object type that the json serializer can not serialize it, please pass the appropriate type
         conversion through this dictionary.
 
+        kwargs: Any other kwargs you pass will be passed on to Python's json.dumps()
+
         **Example**
 
         Serialize custom objects
@@ -147,7 +149,7 @@ class SerializationMixin:
             '{"type_changes": {"root": {"old_type": "A", "new_type": "B", "old_value": "obj A", "new_value": "obj B"}}}'
         """
         dic = self.to_dict(view_override=TEXT_VIEW)
-        return json.dumps(dic, default=json_convertor_default(default_mapping=default_mapping))
+        return json.dumps(dic, default=json_convertor_default(default_mapping=default_mapping), **kwargs)
 
     def to_dict(self, view_override=None):
         """
@@ -364,7 +366,7 @@ def load_path_content(path, file_type=None):
     if file_type == 'json':
         with open(path, 'r') as the_file:
             content = json.load(the_file)
-    elif file_type in {'yaml', '.yml'}:
+    elif file_type in {'yaml', 'yml'}:
         if yaml is None:  # pragma: no cover.
             raise ImportError('Pyyaml needs to be installed.')  # pragma: no cover.
         with open(path, 'r') as the_file:
@@ -426,7 +428,7 @@ def _save_content(content, path, file_type, keep_backup=True):
     if file_type == 'json':
         with open(path, 'w') as the_file:
             content = json.dump(content, the_file)
-    elif file_type in {'yaml', '.yml'}:
+    elif file_type in {'yaml', 'yml'}:
         if yaml is None:  # pragma: no cover.
             raise ImportError('Pyyaml needs to be installed.')  # pragma: no cover.
         with open(path, 'w') as the_file:
